@@ -192,6 +192,8 @@ sub add_paths_for_mixdown_handling {
 	logsub("&add_paths_for_mixdown_handling");
 
 	if ($tn{Mixdown}->rec_status eq REC){
+		# don't monitor via soundcard
+		$g->delete_edge('Master','soundcard_out');
 		my @p = (($mode->mastering ? 'Boost' : 'Master'), ,'Mixdown', 'wav_out');
 		$g->add_path(@p);
 		$g->set_vertex_attributes('Mixdown', {
@@ -460,14 +462,14 @@ sub setup_requires_realtime {
 	if( $prof eq 'auto'){
 		grep{ ! $_->is_mix_track 
 				  and $_->is_user_track 
-				  and $_->rec_status eq REC 
+				  and $_->rec_status =~ /REC|MON/
 			} Audio::Nama::audio_tracks() 
 	} elsif ( $prof eq 'realtime') {
 		my @fields = qw(soundcard jack_client jack_manual jack_ports_list);
 		grep { has_vertex("$_\_in") } @fields 
 			or grep { has_vertex("$_\_out") } @fields
 	}
-	elsif ( $prof eq 'nonrealtime' or !$prof){ 0 }
+	elsif ( $prof eq 'nonrealtime' or !$prof){}
 }
 
 sub has_vertex { $g->has_vertex($_[0]) }
