@@ -206,7 +206,6 @@ sub find_effect {
 					edits
 					fades
 					command_line_options
-					man_page
                 ) ;
 
 %{$help->{topic}} = (
@@ -217,7 +216,6 @@ help => <<HELP,
    help <ladspa_id>        - invoke analyseplugin for info on a LADSPA id
    help <topic_number>     - list commands under <topic_number> 
    help <topic_name>       - list commands under <topic_name> (lower case)
-   help yml                - browse command source file
 HELP
 
 project => <<PROJECT,
@@ -651,7 +649,6 @@ help is available for the following topics:
 12 Edits
 13 Fades
 14 Command line options
-15 Man page
 
 HELP
 
