@@ -19,7 +19,6 @@ our $VERSION = 1.0;
 use Audio::Nama::Util qw(freq input_node dest_type dest_string join_path);
 use Audio::Nama::Assign qw(json_out);
 use vars qw($n %by_name @by_index %track_names %by_index);
-our @ISA = 'Audio::Nama::Wav';
 use Audio::Nama::Object qw(
 					class 			
 					is_mix_track		
@@ -214,6 +213,18 @@ sub maybe_monitor { # ordinary sub, not object method
 	return OFF;
 }
 
+sub targets { # WAV file targets, distinct from 'target' attribute
+	my $self = shift;
+	Audio::Nama::Wav::targets(dir => $self->dir, name => $self->basename)
+}
+sub versions {
+	my $self = shift;
+	Audio::Nama::Wav::versions(dir => $self->dir, name => $self->basename) 
+}
+sub last { 
+	my $self = shift;
+	Audio::Nama::Wav::last(dir => $self->dir, name => $self->basename) || 0 
+}
 # if you belong to a bus with an opinion, go that way
 sub engine_group {
 	my $track = shift;
@@ -272,7 +283,7 @@ sub rec_status {
 		elsif ($source_type eq 'bus')	{ return REC } # maybe $track->rw ??
 		else { return OFF }
 	}
-	elsif( $track->rw eq MON){ 'MON' }
+	elsif( $track->rw eq MON){ MON }
 
 	# set PLAY status if possible
 	
@@ -523,10 +534,15 @@ sub set_source {
 		Audio::Nama::pager($track->name, ": input unchanged, $object");
 	} else {
 		Audio::Nama::pager("Track ",$track->name, ": source set to $object");
+		if (transition_to_null($old_source, $new_source))
+		{
+			Audio::Nama::pager("Track ",$track->name, ": null input, toggling to MON");
+			$track->set(rw => MON) if $track->rw eq REC;		
+		}
 	}
 }
 {
-my $null_re = /^(rt)?null$/;
+my $null_re = qr/^\s*(rt)?null\s*$/;
 sub transition_from_null {
 	my ($old, $new) = @_;
 	$old =~ /$null_re/ and $new !~ /$null_re/
@@ -537,7 +553,6 @@ sub transition_to_null {
 }
 }
 
-
 sub set_version {
 	my ($track, $n) = @_;
 	my $name = $track->name;
@@ -729,7 +744,7 @@ sub mute {
 	$track->set(old_vol_level => $vol->params->[0]);
 	
 	$nofade 
-		? $vol->_modify_effect(1, $track->mute_level)
+		? $vol->_modify_effect(1, $vol->mute_level)
 		: $vol->fadeout
 }
 sub unmute {
@@ -753,6 +768,8 @@ sub apply_ops {
 }
 sub import_audio  { 
 	my $track = shift;
+	Audio::Nama::throw($track->name.": Cannot import audio to system track"), 
+		return if ! $track->is_user_track;
 	my ($path, $frequency) = @_; 
 	$path = Audio::Nama::expand_tilde($path);
 	my $version  = $track->last + 1;
@@ -781,7 +798,7 @@ sub import_audio  {
 		my $path = join_path(Audio::Nama::project_dir()."convert.ecs");
 		write_file($path, $ecs);
 		Audio::Nama::load_ecs($path) or Audio::Nama::throw("$path: load failed, aborting"), return;
-		eval_iam('start');
+		Audio::Nama::eval_iam('start');
 		Audio::Nama::sleeper(0.2); sleep 1 while Audio::Nama::engine_running();
 	} 
 	Audio::Nama::restart_wav_memoize() if $config->{opts}->{R}; # usually handled by reconfigure_engine() 
@@ -1024,8 +1041,19 @@ Mid High Boost );
 sub is_user_track { ! $system_track{$_[0]->name} }
 sub is_system_track { $system_track{$_[0]->name} } 
 }
+sub is_comment {
+	my $self = shift;
+	$Audio::Nama::project->{track_comments}->{$self->name}	
+}
+sub is_version_comment {
+	my $self = shift;
+	my $version = shift;
+	my $comments = $project->{track_version_comments}->{$self->name}->{$version};
+	$comments and $comments->{user}
+}
 } # end package
 
+
 # subclasses
 
 
@@ -1038,14 +1066,14 @@ no warnings qw(uninitialized redefine);
 our @ISA = 'Audio::Nama::Track';
 sub rec_status {
 	my $track = shift;
- 	$track->rw ne OFF ? 'MON' : 'OFF' 
+ 	$track->rw ne OFF ? MON : OFF 
 }
 sub destination {
 	my $track = shift; 
-	return 'Mixdown' if $tn{Mixdown}->rec_status eq 'REC';
+	return 'Mixdown' if $tn{Mixdown}->rec_status eq REC;
 	return $track->SUPER() if $track->rec_status ne OFF
 }
-#sub rec_status_display { $_[0]->rw ne OFF ? 'PLAY' : 'OFF' }
+#sub rec_status_display { $_[0]->rw ne OFF ? PLAY : OFF }
 sub busify {}
 sub unbusify {}
 }
@@ -1059,7 +1087,7 @@ our @ISA = 'Audio::Nama::SimpleTrack';
 sub rec_status{
 	my $track = shift;
  	return OFF if $track->engine_group ne $this_engine->name;
-	$mode->{mastering} ? MON :  'OFF';
+	$mode->{mastering} ? MON :  OFF;
 }
 sub source_status {}
 sub group_last {0}
@@ -1100,14 +1128,19 @@ sub send_id { $tn{$_[0]->target}->send_id}
 sub dir { $tn{$_[0]->target}->dir }
 }
 {
-package Audio::Nama::BoostTrack; # for instrument monitor bus
+package Audio::Nama::BoostTrack; 
+#
+# this subclass, intended for the single track "Boost",
+# disables routing of the mastering network
+# when the mastering mode is disabled.
+
 use Audio::Nama::Globals qw(:all);
 use Modern::Perl; use Audio::Nama::Log qw(logpkg);
 no warnings qw(uninitialized redefine);
 our @ISA = 'Audio::Nama::SlaveTrack';
 sub rec_status{
 	my $track = shift;
-	$mode->{mastering} ? MON :  'OFF';
+	$mode->{mastering} ? MON :  OFF;
 }
 }
 {
@@ -1156,7 +1189,7 @@ sub destination {
 }
 sub rec_status {
 	my $track = shift;
-	return REC if $track->rw eq 'REC';
+	return REC if $track->rw eq REC;
 	Audio::Nama::Track::rec_status($track);
 }
 sub forbid_user_ops { 1 }
@@ -1337,7 +1370,7 @@ sub add_track_alias {
 	my $target; 
 	if 		( $tn{$track} ){ $target = $track }
 	elsif	( $ti{$track} ){ $target = $ti{$track}->name }
-	add_track(  $name, target => $target );
+	add_track(  $name, target => $target, width => $tn{$target}->width);
 }
 # create read-only track pointing at WAV files of specified
 # track name in a different project
@@ -1349,7 +1382,10 @@ sub add_track_alias_project {
 	if ( -d $dir ){
 		if ( glob "$dir/$track*.wav"){
 			Audio::Nama::pager("Found target WAV files.\n");
-			my @params = (target => $track, project => $project_name);
+			my @params = (
+				target => $track, 
+				project => $project_name,
+			);
 			add_track( $name, @params );
 		} else { Audio::Nama::throw("$project_name:$track - No WAV files found.  Skipping.\n"), return; }
 	} else { 
